API Reference
=============

Helper functions
~~~~~~~~~~~~~~~~

.. py:currentmodule:: cid

.. autofunction:: make_cid

.. autofunction:: is_cid

.. autofunction:: from_string

.. autofunction:: from_bytes

CID classes
~~~~~~~~~~~

.. autoclass:: CIDv0
    :show-inheritance:
    :members:
    :inherited-members:
    :undoc-members:

.. autoclass:: CIDv1
    :show-inheritance:
    :members:
    :inherited-members:
    :undoc-members:
